@@ -4,10 +4,10 @@ KISSmetrics template tags.
 
 from __future__ import absolute_import
 
+import json
 import re
 
 from django.template import Library, Node, TemplateSyntaxError
-from django.utils import simplejson
 
 from analytical.utils import is_internal_ip, disable_html, get_identity, \
         get_required_setting
@@ -35,9 +35,11 @@ TRACKING_CODE = """
 IDENTIFY_CODE = "_kmq.push(['identify', '%s']);"
 EVENT_CODE = "_kmq.push(['record', '%(name)s', %(properties)s]);"
 PROPERTY_CODE = "_kmq.push(['set', %(properties)s]);"
+ALIAS_CODE = "_kmq.push(['alias', '%s', '%s']);"
 
 EVENT_CONTEXT_KEY = 'kiss_metrics_event'
 PROPERTY_CONTEXT_KEY = 'kiss_metrics_properties'
+ALIAS_CONTEXT_KEY = 'kiss_metrics_alias'
 
 register = Library()
 
@@ -67,16 +69,22 @@ class KissMetricsNode(Node):
         identity = get_identity(context, 'kiss_metrics')
         if identity is not None:
             commands.append(IDENTIFY_CODE % identity)
+        try:
+            properties = context[ALIAS_CONTEXT_KEY]
+            key, value = properties.popitem()
+            commands.append(ALIAS_CODE % (key,value))
+        except KeyError:
+            pass                         
         try:
             name, properties = context[EVENT_CONTEXT_KEY]
             commands.append(EVENT_CODE % {'name': name,
-                    'properties': simplejson.dumps(properties)})
+                    'properties': json.dumps(properties, sort_keys=True)})
         except KeyError:
             pass
         try:
             properties = context[PROPERTY_CONTEXT_KEY]
             commands.append(PROPERTY_CODE % {
-                    'properties': simplejson.dumps(properties)})
+                    'properties': json.dumps(properties, sort_keys=True)})
         except KeyError:
             pass
         html = TRACKING_CODE % {'api_key': self.api_key,
