@@ -8,22 +8,58 @@ from django.conf import settings
 from django.contrib.sites.models import Site
 from django.http import HttpRequest
 from django.template import Context
+from django.test import TestCase
 
 from analytical.templatetags.chartbeat import ChartbeatTopNode, \
         ChartbeatBottomNode
-from analytical.tests.utils import TagTestCase
+from analytical.tests.utils import TagTestCase, with_apps, without_apps, \
+        override_settings, SETTING_DELETED
 from analytical.utils import AnalyticalException
 
 
+@without_apps('django.contrib.sites')
+@override_settings(CHARTBEAT_USER_ID='12345')
+class ChartbeatTagTestCaseNoSites(TestCase):
+    def test_rendering_setup_no_site(self):
+        r = ChartbeatBottomNode().render(Context())
+        self.assertTrue('var _sf_async_config={"uid": "12345"};' in r, r)
+
+
+@with_apps('django.contrib.sites')
+@override_settings(CHARTBEAT_USER_ID='12345')
+class ChartbeatTagTestCaseWithSites(TestCase):
+    def setUp(self):
+        from django.core.management import call_command
+        from django.db.models import loading
+        loading.cache.loaded = False
+        call_command("syncdb", verbosity=0)
+
+    def test_rendering_setup_site(self):
+        site = Site.objects.create(domain="test.com", name="test")
+        with override_settings(SITE_ID=site.id):
+            r = ChartbeatBottomNode().render(Context())
+            self.assertTrue(re.search(
+                    'var _sf_async_config={.*"uid": "12345".*};', r), r)
+            self.assertTrue(re.search(
+                    'var _sf_async_config={.*"domain": "test.com".*};', r), r)
+
+    @override_settings(CHARTBEAT_AUTO_DOMAIN=False)
+    def test_auto_domain_false(self):
+        """
+        Even if 'django.contrib.sites' is in INSTALLED_APPS, if
+        CHARTBEAT_AUTO_DOMAIN is False, ensure there is no 'domain'
+        in _sf_async_config.
+        """
+        r = ChartbeatBottomNode().render(Context())
+        self.assertTrue('var _sf_async_config={"uid": "12345"};' in r, r)
+
+
+@override_settings(CHARTBEAT_USER_ID='12345')
 class ChartbeatTagTestCase(TagTestCase):
     """
     Tests for the ``chartbeat`` template tag.
     """
 
-    def setUp(self):
-        super(ChartbeatTagTestCase, self).setUp()
-        self.settings_manager.set(CHARTBEAT_USER_ID='12345')
-
     def test_top_tag(self):
         r = self.render_tag('chartbeat', 'chartbeat_top',
                 {'chartbeat_domain': "test.com"})
@@ -50,35 +86,16 @@ class ChartbeatTagTestCase(TagTestCase):
         self.assertTrue(re.search(
                 'var _sf_async_config={.*"domain": "test.com".*};', r), r)
 
+    @override_settings(CHARTBEAT_USER_ID=SETTING_DELETED)
     def test_no_user_id(self):
-        self.settings_manager.delete('CHARTBEAT_USER_ID')
         self.assertRaises(AnalyticalException, ChartbeatBottomNode)
 
+    @override_settings(CHARTBEAT_USER_ID='123abc')
     def test_wrong_user_id(self):
-        self.settings_manager.set(CHARTBEAT_USER_ID='123abc')
         self.assertRaises(AnalyticalException, ChartbeatBottomNode)
 
-    def test_rendering_setup_no_site(self):
-        installed_apps = [a for a in settings.INSTALLED_APPS
-                if a != 'django.contrib.sites']
-        self.settings_manager.set(INSTALLED_APPS=installed_apps)
-        r = ChartbeatBottomNode().render(Context())
-        self.assertTrue('var _sf_async_config={"uid": "12345"};' in r, r)
-
-    def test_rendering_setup_site(self):
-        installed_apps = list(settings.INSTALLED_APPS)
-        installed_apps.append('django.contrib.sites')
-        self.settings_manager.set(INSTALLED_APPS=installed_apps)
-        site = Site.objects.create(domain="test.com", name="test")
-        self.settings_manager.set(SITE_ID=site.id)
-        r = ChartbeatBottomNode().render(Context())
-        self.assertTrue(re.search(
-                'var _sf_async_config={.*"uid": "12345".*};', r), r)
-        self.assertTrue(re.search(
-                'var _sf_async_config={.*"domain": "test.com".*};', r), r)
-
+    @override_settings(ANALYTICAL_INTERNAL_IPS=['1.1.1.1'])
     def test_render_internal_ip(self):
-        self.settings_manager.set(ANALYTICAL_INTERNAL_IPS=['1.1.1.1'])
         req = HttpRequest()
         req.META['REMOTE_ADDR'] = '1.1.1.1'
         context = Context({'request': req})
